==> haskell-process-extras-0.7.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: process-extras
version: 0.7.2
id: process-extras-0.7.2-FedjVPR9XneFChin9CBiB6
key: process-extras-0.7.2-FedjVPR9XneFChin9CBiB6
license: MIT
maintainer: David Fox <dsf@seereason.com>
homepage: https://github.com/seereason/process-extras
synopsis: Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.
category: System
author: David Lazar, Bas van Dijk, David Fox
exposed: True
indefinite: False
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy
hidden-modules: Utils
abi: 5b4084707e6a8ca29e7acea716584b27
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/process-extras-0.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/process-extras-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/process-extras-0.7.2
hs-libraries: HSprocess-extras-0.7.2-FedjVPR9XneFChin9CBiB6
depends:
    base-4.10.1.0 data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65
    ListLike-4.5.1-1zYVaiynF9HHU8yJ2KadEF
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH process-1.6.1.0
    bytestring-0.10.8.2 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    deepseq-1.4.3.0 generic-deriving-1.12-8a2PXMbzwwpF63bxm1epxM
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65=f057e993f72fa1f980dd728ed8010ca1
             ListLike-4.5.1-1zYVaiynF9HHU8yJ2KadEF=a7961db8babfd0292631905fed4fd198
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             generic-deriving-1.12-8a2PXMbzwwpF63bxm1epxM=30f6f75ad134f2e05d57b048fc1877aa
haddock-interfaces: /usr/share/doc/haskell-process-extras/html/process-extras.haddock
haddock-html: /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-process-extras-0.7.2-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: process-extras
version: 0.7.2
id: process-extras-0.7.2-H0hRFA7UNtnEg23CfhFrz6
key: process-extras-0.7.2-H0hRFA7UNtnEg23CfhFrz6
license: MIT
maintainer: David Fox <dsf@seereason.com>
homepage: https://github.com/seereason/process-extras
synopsis: Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.
category: System
author: David Lazar, Bas van Dijk, David Fox
exposed: True
indefinite: False
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy
hidden-modules: Utils
abi: 087473dfbcd3323e6cc30a033ea31343
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/process-extras-0.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/process-extras-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/process-extras-0.7.2
hs-libraries: HSprocess-extras-0.7.2-H0hRFA7UNtnEg23CfhFrz6
depends:
    base-4.10.1.0 data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65
    ListLike-4.5.1-KFKfeQuxO1W9IW5oDsUSo6
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH process-1.6.1.0
    bytestring-0.10.8.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    deepseq-1.4.3.0 generic-deriving-1.12.1-5xFQbdWOF4z1YGQG2uW3ZD
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65=f057e993f72fa1f980dd728ed8010ca1
             ListLike-4.5.1-KFKfeQuxO1W9IW5oDsUSo6=cca53501bf74d229da50ee02ac43c594
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             generic-deriving-1.12.1-5xFQbdWOF4z1YGQG2uW3ZD=458a052e1510088d2839554c69a6e1c5
haddock-interfaces: /usr/share/doc/haskell-process-extras/html/process-extras.haddock
haddock-html: /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
